@@ -1,5 +1,6 @@
 from asyncio import CancelledError
 from aiohttp import web, WSMsgType
+from aiohttp.helpers import call_later
 from aiohttp_middlewares import cors_middleware
 from datetime import datetime
 from cowait.utils import EventEmitter
@@ -9,6 +10,28 @@ from .auth_middleware import AuthMiddleware
 from .errors import SocketError
 
 
+class FixedWebSocketResponse(web.WebSocketResponse):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+    async def _ping(self):
+        try:
+            await self._writer.ping()
+        except ConnectionResetError:
+            pass
+
+    def _send_heartbeat(self) -> None:
+        if self._heartbeat is not None and not self._closed:
+            assert self._loop is not None
+            self._loop.create_task(self._ping())  # type: ignore[union-attr]
+
+            if self._pong_response_cb is not None:
+                self._pong_response_cb.cancel()
+            self._pong_response_cb = call_later(
+                self._pong_not_received, self._pong_heartbeat, self._loop
+            )
+
+
 class Server(EventEmitter):
     def __init__(self, port, middlewares: list = []):
         super().__init__()
@@ -34,7 +57,7 @@ class Server(EventEmitter):
         self.add_get(f'/{WS_PATH}', self.handle_client)
 
     async def handle_client(self, request):
-        ws = web.WebSocketResponse(
+        ws = FixedWebSocketResponse(
             timeout=30.0,
             autoping=True,
             heartbeat=5.0,
@@ -50,25 +73,23 @@ class Server(EventEmitter):
                 msg = await ws.receive()
                 if msg.type == WSMsgType.CLOSE:
                     break
-                elif msg.type == WSMsgType.CLOSE:
-                    break
                 elif msg.type == WSMsgType.ERROR:
                     raise SocketError(ws.exception())
                 elif msg.type == WSMsgType.BINARY:
                     raise SocketError('Unexpected binary message')
-
-                event = msg.json()
-                if conn.rpc.intercept_event(**event):
-                    continue
-                await self.emit(**event, conn=conn)
+                elif msg.type == WSMsgType.TEXT:
+                    event = msg.json()
+                    if conn.rpc.intercept_event(**event):
+                        continue
+                    await self.emit(**event, conn=conn)
 
             await self.emit(type=ON_CLOSE, conn=conn)
 
-        except CancelledError as e:
-            raise e
+        except CancelledError:
+            await self.emit(type=ON_CLOSE, conn=conn)
 
-        except SocketError as e:
-            await self.emit(type=ON_ERROR, conn=conn, error=str(e))
+        except SocketError:
+            await self.emit(type=ON_CLOSE, conn=conn, error=str(e))
 
         finally:
             # disconnected
